@@ -290,7 +290,9 @@ module java.base {
         jdk.crypto.cryptoki,
         jdk.crypto.ec,
         jdk.security.auth;
-    exports sun.security.provider.certpath to java.naming;
+    exports sun.security.provider.certpath to
+        java.naming,
+        jdk.jartool;
     exports sun.security.rsa to
         jdk.crypto.cryptoki,
         jdk.crypto.mscapi;
